# -*- coding: utf-8 -*-


import numpy as np
from pydantic import BaseModel


class SpaceBase(BaseModel):
    id: str | None
    realtime_temperature: float | None


class Space(SpaceBase):
    equipment: list | None
    temperature_target: float | None = np.NAN
    comfortable_temperature: float | None = np.NAN
    diff: float | None = np.NAN


class SpaceATVA(Space):
    vav_default_weight: float | None = np.NAN
    vav_temporary_weight: float | None = np.NAN
    vav_temporary_update_time: str | None = ""


class SpaceATAH(Space):
    ahu_default_weight: float | None
    ahu_temporary_weight: float | None
    ahu_temporary_update_time: str = ""


class SpaceATFU(SpaceBase):
    realtime_co2: float | None
    hcho: float | None
